
======================================================================================
FortLab: Kernel Extraction and Tool Development Framework for Fortran Applications.
======================================================================================

**FortLab** is a Python framework that makets it easy for users to create a kernel-based tools for Fortran applications. With FortLab, user can extract a part of Fortran software and make it a stand-alone software. In addition, users can use its built-in functions to build their own kernel-based analysis tools.


FortLab documentation: `https://fortlab.readthedocs.io <https://fortlab.readthedocs.io/>`_

Installation
-------------

The easiest way to install fortlab is to use the pip python package manager.

        >>> pip install fortlab

You can install fortlab from github code repository if you want to try the latest version.

        >>> git clone https://github.com/grnydawn/fortlab.git
        >>> cd fortlab
        >>> python setup.py install

Usage
-----------
